#Code for analyzing the influence of electric current transfer pathways on lightning disturbance characteristics
#last edited by E.M. Gora for submission on Feb. 20, 2023

#open library
library(dplyr)
library(lme4)
library(car)
library(ggplot2)
library(extrafont)
loadfonts(device="win")

#remove old data
rm(list=ls())


#create ggplot theme
theme_basis<-theme(axis.title = element_text(family = "Arial", color="black", face="bold", size=16))+
  theme(axis.text.y=element_text(family = "Arial", 
                                 colour="black", face ="bold", size = 14)) +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line.x = element_line(colour = "black"),
        axis.line.y = element_line(colour = "black"),axis.ticks = element_line(colour="black"))+
  theme(axis.text.x = element_text(family = "Arial", colour="black", face ="bold", size = 14))

#import data
setwd("G:/My Drive/Lightning/Electrical_connections/data/")
complete_data <- read.csv("current_transfer_bystrike.csv")
str(complete_data)

######################################################
#for the predictions based on the proportion of trees with contact or flashover, drop strikes that were not categorized
#drop strikes that have no proportion of trees assigned a current value

#how many strikes lack any assignments?
summary(complete_data$total_assigned_current==0) #0 strikes

#how many only have direct?
summary(complete_data$total_assigned_current==1&complete_data$direct_count==1)
#21 strikes

#drop all strike with no current assignments apart from "direct"
complete_data_wcurrent <- complete_data[complete_data$total_assigned_current!=0&complete_data$total_assigned_current!=1,]
nrow(complete_data_wcurrent)#now 73 strikes

#drop strikes 21 and 25 because they were censused too late for current source estimates
complete_data_wcurrent<-complete_data_wcurrent[complete_data_wcurrent$strike!="25"&complete_data_wcurrent$strike!="21"&
                                                 complete_data_wcurrent$strike!="18026"&complete_data_wcurrent$strike!="25",]
nrow(complete_data_wcurrent)

#5 strikes had inconsistent assignment of current sources (i.e., <50% of their trees assigned a current source)
#we can remove these and still have 66 lightning strikes for these analyses
complete_data_wcurrent <- complete_data_wcurrent[complete_data_wcurrent$total_assigned_current/complete_data_wcurrent$total_trees>.5,]
nrow(complete_data_wcurrent)# we now have 66 remaining strikes with great data

#calculate the proportion of secondary trees assigned a source that were from contact
complete_data_wcurrent$prop_contact<-complete_data_wcurrent$contact_count/(complete_data_wcurrent$contact_count+complete_data_wcurrent$flashover_count)
#we do not use "total_assinged_current" because this also includes "direct" and "direct" trees could never be contact or flashover
hist(complete_data_wcurrent$prop_contact)
sum(complete_data_wcurrent$total_assigned_current)#1434 trees assigned current
sum(complete_data_wcurrent$total_assigned_current)-sum(complete_data_wcurrent$direct_count)
#1369 trees that were not directly struck were assigned current
sum(complete_data_wcurrent$tree_count)#1681 total trees in these 66 strikes
sum(complete_data_wcurrent$total_assigned_current)/sum(complete_data_wcurrent$tree_count)
#85.3% of trees assigned current source

#what proportion of direct connections are caused by lianas?
sum(complete_data_wcurrent$liana_contact_count)/sum(complete_data_wcurrent$contact_count)*100
#59.7% of all contact was because of liana connections

#what percent of total connections were caused by direct contact?
sum(complete_data_wcurrent$contact_count)/(sum(complete_data_wcurrent$total_assigned_current))*100
#14.4% of trees assigned current had direct physical contact

#calculate proportion of total current sources that were lianas
complete_data_wcurrent$prop_liana<-complete_data_wcurrent$any_liana_count/(complete_data_wcurrent$total_assigned_current-complete_data_wcurrent$direct_count)
sum(complete_data_wcurrent$any_liana_count)/(sum(complete_data_wcurrent$total_assigned_current))*100
#19.3% of trees assigned non-direct current had liana-based connections (280 of 1393 trees) - 44% of these trees (N = 123) lianas had direct physical contact

#also calculate the liana non-contact transfers and their proportion
complete_data_wcurrent$liana_noncontact<-complete_data_wcurrent$any_liana_count-complete_data_wcurrent$liana_contact_count
complete_data_wcurrent$prop_liana_noncontact<-complete_data_wcurrent$liana_noncontact/(complete_data_wcurrent$total_assigned_current-complete_data_wcurrent$direct_count)
sum(complete_data_wcurrent$liana_noncontact)/(sum(complete_data_wcurrent$total_assigned_current))*100
#10.7% of trees had electrical connections caused by lianas without physical contact

#calculate liana contact transfers and their proportion
complete_data_wcurrent$liana_contact<-complete_data_wcurrent$any_liana_count - complete_data_wcurrent$liana_noncontact
complete_data_wcurrent$prop_liana_contact<-complete_data_wcurrent$liana_contact/(complete_data_wcurrent$total_assigned_current-complete_data_wcurrent$direct_count)
sum(complete_data_wcurrent$liana_contact)/(sum(complete_data_wcurrent$total_assigned_current))*100
#8.6% of trees had electrical connections caused by lianas  physical contact

#also calculate the tree non-contact transfers and their proportion
complete_data_wcurrent$tree_noncontact<-complete_data_wcurrent$total_assigned_current - (complete_data_wcurrent$contact_count+complete_data_wcurrent$liana_noncontact + complete_data_wcurrent$direct_count)
complete_data_wcurrent$prop_tree_noncontact<-complete_data_wcurrent$tree_noncontact/(complete_data_wcurrent$total_assigned_current-complete_data_wcurrent$direct_count)
sum(complete_data_wcurrent$tree_noncontact)/sum(complete_data_wcurrent$total_assigned_current)
#70.4% of trees had electrical connections caused by trees without physical contact

#calculate tree contact transfers and their proportion
complete_data_wcurrent$tree_contact<-complete_data_wcurrent$total_assigned_current - (complete_data_wcurrent$tree_noncontact+complete_data_wcurrent$any_liana_count + complete_data_wcurrent$direct_count)
complete_data_wcurrent$prop_tree_contact<-complete_data_wcurrent$tree_contact/(complete_data_wcurrent$total_assigned_current-complete_data_wcurrent$direct_count)
sum(complete_data_wcurrent$tree_contact)/(sum(complete_data_wcurrent$total_assigned_current))*100
#5.8% of trees had electrical connections caused by lianas  physical contact

#the proportions of noncontact (liana+tree) and contact should equal 1
complete_data_wcurrent$prop_tree_noncontact+complete_data_wcurrent$prop_liana_noncontact+complete_data_wcurrent$prop_contact
#they all add to 1

#the proportions of noncontact (liana+tree) and contact (liana + tree) should equal 1
complete_data_wcurrent$prop_tree_noncontact+complete_data_wcurrent$prop_liana_noncontact+complete_data_wcurrent$prop_liana_contact+complete_data_wcurrent$prop_tree_contact
#they do add to 1

#############################################################
#what are the range of contributions in lianas
summary(complete_data_wcurrent$prop_liana)
summary(complete_data_wcurrent$prop_liana_contact)
summary(complete_data_wcurrent$prop_liana_noncontact)

#plot the distributions of current sources per-strike
str(complete_data_wcurrent)
orderedfig_df <- complete_data_wcurrent %>% 
  arrange(desc(prop_liana),desc(prop_liana_contact))

orderedfig_df$liana_importance_rank <- seq(1,nrow(orderedfig_df),1)
str(orderedfig_df)

library(tidyr)
#count trees not assigned current
orderedfig_df$no_current_source <- orderedfig_df$total_trees-orderedfig_df$total_assigned_current

orderedfig_df_longer <- pivot_longer(orderedfig_df,cols = c("no_current_source","direct_count",
                                    "liana_contact","liana_noncontact","tree_contact","tree_noncontact"),
             names_to = "Source",values_to = "trees_per_group")

orderedfig_df_longer<- orderedfig_df_longer[,c("Source","trees_per_group","liana_importance_rank")]

#reorder the source data
orderedfig_df_longer$Source <- factor(orderedfig_df_longer$Source,
                                      levels = c("no_current_source","direct_count","liana_contact","liana_noncontact",
  "tree_contact","tree_noncontact"))

current_source_stacked <- ggplot(data = orderedfig_df_longer, aes(x = liana_importance_rank,y = trees_per_group)) +
  geom_col(aes(fill = Source),color="black",size = .1) +
  scale_fill_manual(values = c("grey85","black","blue","cyan","red3","light coral"),
                    labels = c("Source unknown","Direct strike","Liana contact","Liana flashover",
                    "Tree contact","Tree flashover")) +
  theme_basis + theme(legend.position = c(.82,.75),legend.background=element_blank(),
                      legend.title = element_blank(),
                      legend.text = element_text(family = "Arial",size=10,face = "bold")) +
  scale_x_continuous("Liana rank importance", expand = c(0,0), breaks = seq(0,65,5),
                     labels = c("0",rep("",3),"20",rep("",3),"40",rep("",3),"60","")) +
  scale_y_continuous("Damaged trees", expand = c(0,0), breaks = seq(0,110,10),
                     labels = c("0","","20","","40","","60","","80","","100",""))
  
current_source_stacked

ggsave("current_source_stacked.tiff",current_source_stacked,dpi = 600,
       height = 2,width = 3.25,scale = 1.8,compression="lzw")
#############################################################
#test for correlation between prop_liana, connectedness, and central tree DBH
cor.test(complete_data_wcurrent$prop_liana_noncontact,complete_data_wcurrent$prop_contact)
#no correlation and no double counting
cor.test(complete_data_wcurrent$DBH.mm,complete_data_wcurrent$prop_contact)
#no correlation
cor.test(complete_data_wcurrent$DBH.mm,complete_data_wcurrent$prop_liana_noncontact)
#no correlation
cor.test(complete_data_wcurrent$DBH.mm,complete_data_wcurrent$disturbed_area)
#no correlation

cor.test(complete_data_wcurrent$tree_noncontact,complete_data_wcurrent$prop_liana_noncontact)
#no correlation
cor.test(complete_data_wcurrent$tree_noncontact,complete_data_wcurrent$prop_contact)
#no correlation

################################################################################
complete_data_wcurrent$disturbed_area_ha<-complete_data_wcurrent$disturbed_area/10000

#include all possible terms in the model to test for colinearity 
treecount_current_wtreeflash<-lm(log(tree_count)~prop_liana_contact+prop_tree_contact+prop_liana_noncontact+ 
                                   prop_tree_noncontact, data = complete_data_wcurrent)
vif(treecount_current_wtreeflash)
#vif cannot even be run on this model because there is perfect colinearity
### that is, the proportions necessarily add up to 1

#drop the tree flashover term
treecount_current_wtreeflash<-lm(log(tree_count)~prop_liana_contact+prop_tree_contact+prop_liana_noncontact, 
                                 data = complete_data_wcurrent)
vif(treecount_current_wtreeflash)
#dropping "prop_tree_noncontact" fixes the problem
#this model assumes that "prop_tree_noncontact" of 100% equals the intercept

#####################################################################
### -- Run all models, separate the types of  contact transfer -- ###
#####################################################################
#test how current transfer predicts variation in disturbed area

#run analyses comparing current transfer to area
disturbarea_3term<-glm(disturbed_area~prop_liana_contact + prop_liana_noncontact + prop_tree_contact,
                 data = complete_data_wcurrent, family = Gamma(link = "inverse"))
Anova(disturbarea_3term, test.statistic = c("LR"))
summary(disturbarea_3term)
plot(disturbarea_3term)#the fit is mediocre - also, nothing is significant

####################################
### --- Count damaged trees --- ###
####################################

######################################################################
#run model with contact split into groups
treecount_3term<-glm(tree_count~prop_liana_contact + prop_liana_noncontact + prop_tree_contact,
                 data = complete_data_wcurrent, family = poisson(link = "log"))
Anova(treecount_3term, test.statistic = c("LR"))#all three predictors are significant
summary(treecount_3term)#more trees killed with more contact and liana flashover
plot(treecount_3term)#decent fit - underprediction of highest values


####################################
### --- Count dead trees --- ###
####################################

countdead_3term<-glm(total.dead~prop_liana_contact + prop_liana_noncontact + prop_tree_contact,
                       data = complete_data_wcurrent, family = poisson(link = "log"))
summary(countdead_3term)
Anova(countdead_3term, test.statistic = c("LR"))#more trees killed with more contact and liana flashover
plot(countdead_3term)#decent fit - underestimate the highest value a bit


####################################
### --- Necromass production --- ###
####################################
totalnecromass_3term<-lm(log(total_necromass_kg/1000)~prop_liana_contact + prop_liana_noncontact + prop_tree_contact,
                       data = complete_data_wcurrent)

summary(totalnecromass_3term)
Anova(totalnecromass_3term)#no terms are significant
plot(totalnecromass_3term)#pretty good fit 

#########################################
### --- Propotion of trees killed --- ###
#########################################
#analyze the proportion of trees killed using simple "contact" without area
propdead_3term<-lm(prop.dead~prop_liana_contact + prop_liana_noncontact +
                       prop_tree_contact, data = complete_data_wcurrent)
summary(propdead_3term)
Anova(propdead_3term)#only liana contact is a significant predictor
plot(propdead_3term)#good fit
vif(propdead_3term)


############################################
### --- Average DBH of damaged trees --- ###
############################################
#analyze variation in mean tree DBH with simple "contact" and without area
meanDBH_3term<-lm(mean_DBH~prop_liana_contact + prop_liana_noncontact +
                      prop_tree_contact, data = complete_data_wcurrent)
summary(meanDBH_3term)
Anova(meanDBH_3term)#liana terms are strongly signficant - weak effect of tree contact
plot(meanDBH_3term)#decent fit

################################
### --- Central tree DBH --- ###
################################
#analyze variation in mean tree DBH with simple "contact" and without area
centralDBH_3term<-lm(DBH.mm~prop_liana_contact + prop_liana_noncontact +
                    prop_tree_contact, data = complete_data_wcurrent)
summary(centralDBH_3term)
Anova(centralDBH_3term)#liana terms are strongly signficant - weak effect of tree contact
plot(centralDBH_3term)#good fit

############################################################################
### --- Plot the results of these analyses to create grid of figures --- ###
############################################################################
#create dataframes for plotting

#liana contact dataframe
plot_liana_contact_df<-as.data.frame(with(complete_data_wcurrent,seq(min(prop_liana_contact),max(prop_liana_contact),length.out = 100)))
colnames(plot_liana_contact_df)<-"prop_liana_contact"
plot_liana_contact_df$prop_liana_noncontact <- mean(complete_data_wcurrent$prop_liana_noncontact)
plot_liana_contact_df$prop_tree_contact <- mean(complete_data_wcurrent$prop_tree_contact)

#tree contact dataframe
plot_tree_contact_df<-as.data.frame(with(complete_data_wcurrent,seq(min(prop_tree_contact),max(prop_tree_contact),length.out = 100)))
colnames(plot_tree_contact_df)<-"prop_tree_contact"
plot_tree_contact_df$prop_liana_contact <- mean(complete_data_wcurrent$prop_liana_contact)
plot_tree_contact_df$prop_liana_noncontact <- mean(complete_data_wcurrent$prop_liana_noncontact)

#liana noncontact dataframe
plot_liana_noncontact_df<-as.data.frame(with(complete_data_wcurrent,seq(min(prop_liana_noncontact),max(prop_liana_noncontact),length.out = 100)))
colnames(plot_liana_noncontact_df)<-"prop_liana_noncontact"
plot_liana_noncontact_df$prop_liana_contact <- mean(complete_data_wcurrent$prop_liana_contact)
plot_liana_noncontact_df$prop_tree_contact <- mean(complete_data_wcurrent$prop_tree_contact)


#create predictions for all response variables, except non-significant area+necromass
#liana contact
plot_liana_contact_df$predicted_treecount <- exp(predict(treecount_3term,plot_liana_contact_df))
plot_liana_contact_df$predicted_treecount_upr <- exp(predict(treecount_3term,plot_liana_contact_df) + predict(treecount_3term,plot_liana_contact_df,se.fit=TRUE)$se.fit*1.96)
plot_liana_contact_df$predicted_treecount_lwr <- exp(predict(treecount_3term,plot_liana_contact_df) - predict(treecount_3term,plot_liana_contact_df,se.fit=TRUE)$se.fit*1.96)
plot_liana_contact_df$predicted_countdead <- exp(predict(countdead_3term,plot_liana_contact_df))
plot_liana_contact_df$predicted_countdead_upr <- exp(predict(countdead_3term,plot_liana_contact_df) + predict(countdead_3term,plot_liana_contact_df,se.fit=TRUE)$se.fit*1.96)
plot_liana_contact_df$predicted_countdead_lwr <- exp(predict(countdead_3term,plot_liana_contact_df) - predict(countdead_3term,plot_liana_contact_df,se.fit=TRUE)$se.fit*1.96)
plot_liana_contact_df$predicted_propdead <- predict(propdead_3term,plot_liana_contact_df)
plot_liana_contact_df$predicted_propdead_upr <- predict(propdead_3term,plot_liana_contact_df) + predict(propdead_3term,plot_liana_contact_df,se.fit=TRUE)$se.fit*1.96
plot_liana_contact_df$predicted_propdead_lwr <- predict(propdead_3term,plot_liana_contact_df) - predict(propdead_3term,plot_liana_contact_df,se.fit=TRUE)$se.fit*1.96
plot_liana_contact_df$predicted_meanDBH <- predict(meanDBH_3term,plot_liana_contact_df)
plot_liana_contact_df$predicted_meanDBH_upr <- predict(meanDBH_3term,plot_liana_contact_df) + predict(meanDBH_3term,plot_liana_contact_df,se.fit=TRUE)$se.fit*1.96
plot_liana_contact_df$predicted_meanDBH_lwr <- predict(meanDBH_3term,plot_liana_contact_df) - predict(meanDBH_3term,plot_liana_contact_df,se.fit=TRUE)$se.fit*1.96

#tree contact
plot_tree_contact_df$predicted_treecount <- exp(predict(treecount_3term,plot_tree_contact_df))
plot_tree_contact_df$predicted_treecount_upr <- exp(predict(treecount_3term,plot_tree_contact_df) + predict(treecount_3term,plot_tree_contact_df,se.fit=TRUE)$se.fit*1.96)
plot_tree_contact_df$predicted_treecount_lwr <- exp(predict(treecount_3term,plot_tree_contact_df) - predict(treecount_3term,plot_tree_contact_df,se.fit=TRUE)$se.fit*1.96)
plot_tree_contact_df$predicted_countdead <- exp(predict(countdead_3term,plot_tree_contact_df))
plot_tree_contact_df$predicted_countdead_upr <- exp(predict(countdead_3term,plot_tree_contact_df) + predict(countdead_3term,plot_tree_contact_df,se.fit=TRUE)$se.fit*1.96)
plot_tree_contact_df$predicted_countdead_lwr <- exp(predict(countdead_3term,plot_tree_contact_df) - predict(countdead_3term,plot_tree_contact_df,se.fit=TRUE)$se.fit*1.96)
plot_tree_contact_df$predicted_propdead <- predict(propdead_3term,plot_tree_contact_df)
plot_tree_contact_df$predicted_propdead_upr <- predict(propdead_3term,plot_tree_contact_df) + predict(propdead_3term,plot_tree_contact_df,se.fit=TRUE)$se.fit*1.96
plot_tree_contact_df$predicted_propdead_lwr <- predict(propdead_3term,plot_tree_contact_df) - predict(propdead_3term,plot_tree_contact_df,se.fit=TRUE)$se.fit*1.96
plot_tree_contact_df$predicted_meanDBH <- predict(meanDBH_3term,plot_tree_contact_df)
plot_tree_contact_df$predicted_meanDBH_upr <- predict(meanDBH_3term,plot_tree_contact_df) + predict(meanDBH_3term,plot_tree_contact_df,se.fit=TRUE)$se.fit*1.96
plot_tree_contact_df$predicted_meanDBH_lwr <- predict(meanDBH_3term,plot_tree_contact_df) - predict(meanDBH_3term,plot_tree_contact_df,se.fit=TRUE)$se.fit*1.96

#liana flashover
plot_liana_noncontact_df$predicted_treecount <- exp(predict(treecount_3term,plot_liana_noncontact_df))
plot_liana_noncontact_df$predicted_treecount_upr <- exp(predict(treecount_3term,plot_liana_noncontact_df) + predict(treecount_3term,plot_liana_noncontact_df,se.fit=TRUE)$se.fit*1.96)
plot_liana_noncontact_df$predicted_treecount_lwr <- exp(predict(treecount_3term,plot_liana_noncontact_df) - predict(treecount_3term,plot_liana_noncontact_df,se.fit=TRUE)$se.fit*1.96)
plot_liana_noncontact_df$predicted_countdead <- exp(predict(countdead_3term,plot_liana_noncontact_df))
plot_liana_noncontact_df$predicted_countdead_upr <- exp(predict(countdead_3term,plot_liana_noncontact_df) + predict(countdead_3term,plot_liana_noncontact_df,se.fit=TRUE)$se.fit*1.96)
plot_liana_noncontact_df$predicted_countdead_lwr <- exp(predict(countdead_3term,plot_liana_noncontact_df) - predict(countdead_3term,plot_liana_noncontact_df,se.fit=TRUE)$se.fit*1.96)
plot_liana_noncontact_df$predicted_propdead <- predict(propdead_3term,plot_liana_noncontact_df)
plot_liana_noncontact_df$predicted_propdead_upr <- predict(propdead_3term,plot_liana_noncontact_df) + predict(propdead_3term,plot_liana_noncontact_df,se.fit=TRUE)$se.fit*1.96
plot_liana_noncontact_df$predicted_propdead_lwr <- predict(propdead_3term,plot_liana_noncontact_df) - predict(propdead_3term,plot_liana_noncontact_df,se.fit=TRUE)$se.fit*1.96
plot_liana_noncontact_df$predicted_meanDBH <- predict(meanDBH_3term,plot_liana_noncontact_df)
plot_liana_noncontact_df$predicted_meanDBH_upr <- predict(meanDBH_3term,plot_liana_noncontact_df) + predict(meanDBH_3term,plot_liana_noncontact_df,se.fit=TRUE)$se.fit*1.96
plot_liana_noncontact_df$predicted_meanDBH_lwr <- predict(meanDBH_3term,plot_liana_noncontact_df) - predict(meanDBH_3term,plot_liana_noncontact_df,se.fit=TRUE)$se.fit*1.96

#look at the dataframes
head(plot_liana_contact_df)
head(plot_tree_contact_df)
head(plot_liana_noncontact_df)
############################################################################
## -- Now add fitted curves to each of the figures below
############################################################################

##################################################
### --- Plot liana flashover relationships --- ###
##################################################

#strong relationship between the propotion in contact (a measure of interconnectedness) and tree counts
tree_count_liana_noncontact<-ggplot(data = complete_data_wcurrent, aes(x = prop_liana_noncontact, y = tree_count))+
  geom_point(size = 1) + theme_basis +
  geom_line(data = plot_liana_noncontact_df, aes(x = prop_liana_noncontact,y = predicted_treecount), color = "black",size=1)+
  geom_ribbon(data = plot_liana_noncontact_df,aes(x = prop_liana_noncontact,y = predicted_treecount,ymax = predicted_treecount_upr,
                                                  ymin = predicted_treecount_lwr), fill = "black",alpha = 0.2)+
  scale_x_continuous(name = "Liana flashover (%)",seq(0,.55,.05),limits = c(0,.46),
                     labels = c("0","","10","","20","","30","","40","","50",""), expand = c(.02,0))+
  scale_y_continuous(name = "Damaged trees", breaks = seq(0,100,10),
                labels = c("0","","20","","40","","60","","80","","100"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

tree_count_liana_noncontact

ggsave("tree_count_liana_noncontact.tiff",tree_count_liana_noncontact,dpi = 600,
       scale = 2, width = 3.25/2, height = 1.5, compression = "lzw")


#relationship between the propotion in contact (a measure of interconnectedness) and tree deaths
dead_trees_liana_noncontact<-ggplot(data = complete_data_wcurrent, aes(x = prop_liana_noncontact, y = total.dead+1))+
  geom_point(size = 1) + theme_basis +
  geom_line(data = plot_liana_noncontact_df, aes(x = prop_liana_noncontact,y = predicted_countdead), color = "black",size=1)+
  geom_ribbon(data = plot_liana_noncontact_df,aes(x = prop_liana_noncontact,y = predicted_countdead,ymax = predicted_countdead_upr,
                                                  ymin = predicted_countdead_lwr), fill = "black",alpha = 0.2)+
  scale_x_continuous(name = "Liana flashover (%)", limits = c(0,.46),seq(0,.55,.05),
                     labels = c("0","","10","","20","","30","","40","","50",""), expand = c(.02,0))+
  scale_y_continuous(name = "Killed trees", breaks = seq(0,35,5),
                     labels = c("0","","10","","20","","30",""))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))+
  coord_cartesian(ylim = c(1,32))

dead_trees_liana_noncontact

ggsave("dead_trees_liana_noncontact.tiff",dead_trees_liana_noncontact,dpi = 600,
       scale = 2, width = 3.25/2, height = 1.5, compression = "lzw")

#strong relationship between the propotion in contact (a measure of interlianacontact) and propotion of trees killed
propdead_liana_noncontact<-ggplot(data = complete_data_wcurrent, aes(x = prop_liana_noncontact, y = prop.dead))+
  geom_point(size = 1) + theme_basis +
  scale_x_continuous(name = "Liana flashover (%)", limits = c(0,.46),seq(0,.55,.05),
                     labels = c("0","","10","","20","","30","","40","","50",""), expand = c(.02,0))+
  scale_y_continuous(name = "Tree mortality (%)",expand = c(0.05,0), breaks = seq(0,.7,.05),
                     labels = c("0","","10","","20","","30","","40","","50","","60","","70"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

propdead_liana_noncontact

ggsave("propdead_liana_noncontact.tiff",propdead_liana_noncontact,dpi = 600,
       scale = 2, width = 3.25/2, height = 1.5, compression = "lzw")

#no connection between lianacontact and necromass
necromass_liana_noncontact<-ggplot(data = complete_data_wcurrent, aes(x = prop_liana_noncontact, y = total_necromass_kg/1000))+
  geom_point(size = 1) + theme_basis +
  scale_x_continuous(name = "Liana flashover (%)", limits = c(0,.46),seq(0,.55,.05),
                     labels = c("0","","10","","20","","30","","40","","50",""), expand = c(.02,0))+
  scale_y_continuous(name = "Biomass turnover (Mg)",expand = c(0.04,0), breaks = seq(0,40,5), 
                     labels = c("0","","10","","20","","30","","40"))+
  coord_cartesian(ylim = c(0,40))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

necromass_liana_noncontact

ggsave("necromass_liana_noncontact.tiff",necromass_liana_noncontact,dpi = 600,
       scale = 2, width = 3.25/2, height = 1.5, compression = "lzw")

#negative relationship between noncontact lianas and damaged tree DBH
meanDBH_liana_noncontact<-ggplot(data = complete_data_wcurrent, aes(x = prop_liana_noncontact, y = mean_DBH))+
  geom_point(size = 1) + theme_basis +
  geom_smooth(method = "lm",color = "black",fill = "black", alpha = .2)+
  scale_x_continuous(name = "Liana flashover (%)", limits = c(0,.46),seq(0,.55,.05),
                     labels = c("0","","10","","20","","30","","40","","50",""), expand = c(.02,0))+
  scale_y_continuous(name = "Mean DBH (mm)",expand = c(0.04,0), breaks = seq(0,650,50), 
                     labels = c("0","","100","","200","","300","","400","","500","","600",""))+
  coord_cartesian(ylim = c(100,650))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

meanDBH_liana_noncontact

ggsave("meanDBH_liana_noncontact.tiff",meanDBH_liana_noncontact,dpi = 600,
       scale = 2, width = 3.25/2, height = 1.5, compression = "lzw")

#plot tree contact versus disturbed area
area_liana_noncontact<-ggplot(data = complete_data_wcurrent, aes(x = prop_liana_noncontact, y = disturbed_area/10000))+
  geom_point(size = 1) + theme_basis +
  scale_x_continuous(name = "Liana flashover (%)", limits = c(0,.46),seq(0,.55,.05),
                     labels = c("0","","10","","20","","30","","40","","50",""), expand = c(.02,0))+
  scale_y_continuous(name = "Disturbed area (ha)",expand = c(0.04,0), breaks = seq(0,.2,.01), 
                     labels = c("0",rep("",9),"0.1",rep("",9),"0.2"),limits = c(0,.2))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

area_liana_noncontact

ggsave("area_liana_noncontact.tiff",area_liana_noncontact,dpi = 600,
       scale = 1.8, width = 6.5/3, height = 1.8, compression = "lzw")


#########################################################
### --- Plot liana physical contact relationships --- ###
#########################################################

#strong relationship between the propotion in contact (a measure of interconnectedness) and tree counts
tree_count_lianacontact<-ggplot(data = complete_data_wcurrent, aes(x = prop_liana_contact, y = tree_count))+
  geom_point(size = 1) + theme_basis +
  geom_line(data = plot_liana_contact_df, aes(x = prop_liana_contact,y = predicted_treecount), color = "black",size=1)+
  geom_ribbon(data = plot_liana_contact_df,aes(x = prop_liana_contact,y = predicted_treecount,ymax = predicted_treecount_upr,
                                              ymin = predicted_treecount_lwr), fill = "black",alpha = 0.2)+
  scale_x_continuous(name = "Liana physical contact (%)", limits = c(0,.51),seq(0,.55,.05),
                     labels = c("0","","10","","20","","30","","40","","50",""), expand = c(.02,0))+
  scale_y_continuous(name = "Damaged trees", breaks = seq(0,100,10),
                     labels = c("0","","20","","40","","60","","80","","100"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

tree_count_lianacontact

ggsave("tree_count_lianacontact.tiff",tree_count_lianacontact,dpi = 600,
       scale = 1.8, width = 6.5/3, height = 1.8, compression = "lzw")

#relationship between the propotion in contact (a measure of interconnectedness) and tree deaths
dead_trees_lianacontact<-ggplot(data = complete_data_wcurrent, aes(x = prop_liana_contact, y = total.dead+1))+
  geom_point(size = 1) + theme_basis +
  geom_line(data = plot_liana_contact_df, aes(x = prop_liana_contact,y = predicted_countdead), color = "black",size=1)+
  geom_ribbon(data = plot_liana_contact_df,aes(x = prop_liana_contact,y = predicted_countdead,ymax = predicted_countdead_upr,
                                               ymin = predicted_countdead_lwr), fill = "black",alpha = 0.2)+
  scale_x_continuous(name = "Liana physical contact (%)", limits = c(0,.51),seq(0,.55,.05),
                     labels = c("0","","10","","20","","30","","40","","50",""), expand = c(.02,0))+
  scale_y_continuous(name = "Killed trees", breaks = seq(0,35,5),
                     labels = c("0","","10","","20","","30",""))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))+
  coord_cartesian(ylim = c(1,32))

dead_trees_lianacontact

ggsave("dead_trees_lianacontact.tiff",dead_trees_lianacontact,dpi = 600,
       scale = 1.8, width = 6.5/3, height = 1.8, compression = "lzw")

#strong relationship between the propotion in contact (a measure of interlianacontact) and propotion of trees killed
propdead_lianacontact<-ggplot(data = complete_data_wcurrent, aes(x = prop_liana_contact, y = prop.dead))+
  geom_point(size = 1) + theme_basis +
  geom_line(data = plot_liana_contact_df, aes(x = prop_liana_contact,y = predicted_propdead), color = "black",size=1)+
  geom_ribbon(data = plot_liana_contact_df,aes(x = prop_liana_contact,y = predicted_propdead,ymax = predicted_propdead_upr,
                                               ymin = predicted_propdead_lwr), fill = "black",alpha = 0.2)+
  scale_x_continuous(name = "Liana physical contact (%)", limits = c(0,.51),seq(0,.55,.05),
                     labels = c("0","","10","","20","","30","","40","","50",""), expand = c(.02,0))+
  scale_y_continuous(name = "Tree mortality (%)",expand = c(0.05,0), breaks = seq(0,.7,.05),
                     labels = c("0","","10","","20","","30","","40","","50","","60","","70"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

propdead_lianacontact

ggsave("propdead_lianacontact.tiff",propdead_lianacontact,dpi = 600,
       scale = 1.8, width = 6.5/3, height = 1.8, compression = "lzw")

#no connection between lianacontact and necromass
necromass_lianacontact<-ggplot(data = complete_data_wcurrent, aes(x = prop_liana_contact, y = total_necromass_kg/1000))+
  geom_point(size = 1) + theme_basis +
  scale_x_continuous(name = "Liana physical contact (%)", limits = c(0,.51),seq(0,.55,.05),
                     labels = c("0","","10","","20","","30","","40","","50",""), expand = c(.02,0))+
  scale_y_continuous(name = "Biomass turnover (Mg)",expand = c(0.04,0), breaks = seq(0,40,5), 
                     labels = c("0","","10","","20","","30","","40"))+
  coord_cartesian(ylim = c(0,40))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

necromass_lianacontact

ggsave("necromass_lianacontact.tiff",necromass_lianacontact,dpi = 600,
       scale = 1.8, width = 6.5/3, height = 1.8, compression = "lzw")

#negative relationship between noncontact lianas and damaged tree DBH
meanDBH_lianacontact<-ggplot(data = complete_data_wcurrent, aes(x = prop_liana_contact, y = mean_DBH))+
  geom_point(size = 1) + theme_basis +
  geom_line(data = plot_liana_contact_df, aes(x = prop_liana_contact,y = predicted_meanDBH), color = "black",size=1)+
  geom_ribbon(data = plot_liana_contact_df,aes(x = prop_liana_contact,y = predicted_meanDBH,ymax = predicted_meanDBH_upr,
                                               ymin = predicted_meanDBH_lwr), fill = "black",alpha = 0.2)+
  scale_x_continuous(name = "Liana physical contact (%)", limits = c(0,.51),seq(0,.55,.05),
                     labels = c("0","","10","","20","","30","","40","","50",""), expand = c(.02,0))+
  scale_y_continuous(name = "Mean DBH (mm)",expand = c(0.04,0), breaks = seq(0,650,50), 
                     labels = c("0","","100","","200","","300","","400","","500","","600",""))+
  coord_cartesian(ylim = c(100,650))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

meanDBH_lianacontact

ggsave("meanDBH_lianacontact.tiff",meanDBH_lianacontact,dpi = 600,
       scale = 1.8, width = 6.5/3, height = 1.8, compression = "lzw")

#plot tree contact versus disturbed area
area_lianacontact<-ggplot(data = complete_data_wcurrent, aes(x = prop_liana_contact, y = disturbed_area/10000))+
  geom_point(size = 1) + theme_basis +
  scale_x_continuous(name = "Liana physical contact (%)", limits = c(0,.51),seq(0,.55,.05),
                     labels = c("0","","10","","20","","30","","40","","50",""), expand = c(.02,0))+
  scale_y_continuous(name = "Disturbed area (ha)",expand = c(0.04,0), breaks = seq(0,.2,.01), 
                     labels = c("0",rep("",9),"0.1",rep("",9),"0.2"),limits = c(0,.2))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

area_lianacontact

ggsave("area_lianacontact.tiff",area_lianacontact,dpi = 600,
       scale = 1.8, width = 6.5/3, height = 1.8, compression = "lzw")

#########################################################
### --- Plot tree physical contact relationships --- ###
#########################################################

#strong relationship between the propotion in contact (a measure of interconnectedness) and tree counts
tree_count_treecontact<-ggplot(data = complete_data_wcurrent, aes(x = prop_tree_contact, y = tree_count))+
  geom_point(size = 1) + theme_basis +
  geom_line(data = plot_tree_contact_df, aes(x = prop_tree_contact,y = predicted_treecount), color = "black",size=1)+
  geom_ribbon(data = plot_tree_contact_df,aes(x = prop_tree_contact,y = predicted_treecount,ymax = predicted_treecount_upr,
                                               ymin = predicted_treecount_lwr), fill = "black",alpha = 0.2)+
  scale_x_continuous(name = "Tree physical contact (%)", limits = c(0,.37),seq(0,.55,.05),
                     labels = c("0","","10","","20","","30","","40","","50",""), expand = c(.02,0))+
  scale_y_continuous(name = "Damaged trees", breaks = seq(0,100,10),
                     labels = c("0","","20","","40","","60","","80","","100"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

tree_count_treecontact

ggsave("tree_count_treecontact.tiff",tree_count_treecontact,dpi = 600,
       scale = 1.8, width = 6.5/3, height = 1.8, compression = "lzw")

#relationship between the propotion in contact (a measure of interconnectedness) and tree deaths
dead_trees_treecontact<-ggplot(data = complete_data_wcurrent, aes(x = prop_tree_contact, y = total.dead+1))+
  geom_point(size = 1) + theme_basis +
  geom_line(data = plot_tree_contact_df, aes(x = prop_tree_contact,y = predicted_countdead), color = "black",size=1)+
  geom_ribbon(data = plot_tree_contact_df,aes(x = prop_tree_contact,y = predicted_countdead,ymax = predicted_countdead_upr,
                                               ymin = predicted_countdead_lwr), fill = "black",alpha = 0.2)+
  scale_x_continuous(name = "Tree physical contact (%)", limits = c(0,.37),seq(0,.55,.05),
                     labels = c("0","","10","","20","","30","","40","","50",""), expand = c(.02,0))+
  scale_y_continuous(name = "Killed trees", breaks = seq(0,35,5),
                     labels = c("0","","10","","20","","30",""))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))+
  coord_cartesian(ylim = c(1,32))

dead_trees_treecontact

ggsave("dead_trees_treecontact.tiff",dead_trees_treecontact,dpi = 600,
       scale = 1.8, width = 6.5/3, height = 1.8, compression = "lzw")

#strong relationship between the propotion in contact (a measure of intertreecontact) and propotion of trees killed
propdead_treecontact<-ggplot(data = complete_data_wcurrent, aes(x = prop_tree_contact, y = prop.dead))+
  geom_point(size = 1) + theme_basis +
  scale_x_continuous(name = "Tree physical contact (%)", limits = c(0,.37),seq(0,.55,.05),
                     labels = c("0","","10","","20","","30","","40","","50",""), expand = c(.02,0))+
  scale_y_continuous(name = "Tree mortality (%)",expand = c(0.05,0), breaks = seq(0,.7,.05),
                     labels = c("0","","10","","20","","30","","40","","50","","60","","70"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

propdead_treecontact

ggsave("propdead_treecontact.tiff",propdead_treecontact,dpi = 600,
       scale = 1.8, width = 6.5/3, height = 1.8, compression = "lzw")

#no connection between treecontact and necromass
necromass_treecontact<-ggplot(data = complete_data_wcurrent, aes(x = prop_tree_contact, y = total_necromass_kg/1000))+
  geom_point(size = 1) + theme_basis +
  scale_x_continuous(name = "Tree physical contact (%)", limits = c(0,.37),seq(0,.55,.05),
                     labels = c("0","","10","","20","","30","","40","","50",""), expand = c(.02,0))+
  scale_y_continuous(name = "Biomass turnover (Mg)",expand = c(0.04,0), breaks = seq(0,40,5), 
                     labels = c("0","","10","","20","","30","","40"))+
  coord_cartesian(ylim = c(0,40))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

necromass_treecontact

ggsave("necromass_treecontact.tiff",necromass_treecontact,dpi = 600,
       scale = 1.8, width = 6.5/3, height = 1.8, compression = "lzw")

#negative relationship between noncontact trees and damaged tree DBH
meanDBH_treecontact<-ggplot(data = complete_data_wcurrent, aes(x = prop_tree_contact, y = mean_DBH))+
  geom_point(size = 1) + theme_basis +
  geom_line(data = plot_tree_contact_df, aes(x = prop_tree_contact,y = predicted_meanDBH), color = "black",size=1,linetype="dashed")+
  geom_ribbon(data = plot_tree_contact_df,aes(x = prop_tree_contact,y = predicted_meanDBH,ymax = predicted_meanDBH_upr,
                                               ymin = predicted_meanDBH_lwr), fill = "black",alpha = 0.2)+
  scale_x_continuous(name = "Tree physical contact (%)", limits = c(0,.37),seq(0,.55,.05),
                     labels = c("0","","10","","20","","30","","40","","50",""), expand = c(.02,0))+
  scale_y_continuous(name = "Mean DBH (mm)",expand = c(0.04,0), breaks = seq(0,650,50), 
                     labels = c("0","","100","","200","","300","","400","","500","","600",""))+
  coord_cartesian(ylim = c(100,650))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

meanDBH_treecontact

ggsave("meanDBH_treecontact.tiff",meanDBH_treecontact,dpi = 600,
       scale = 1.8, width = 6.5/3, height = 1.8, compression = "lzw")

#plot tree contact versus disturbed area
area_treecontact<-ggplot(data = complete_data_wcurrent, aes(x = prop_tree_contact, y = disturbed_area/10000))+
  geom_point(size = 1) + theme_basis +
  scale_x_continuous(name = "Tree physical contact (%)", limits = c(0,.37),seq(0,.55,.05),
                     labels = c("0","","10","","20","","30","","40","","50",""), expand = c(.02,0))+
  scale_y_continuous(name = "Disturbed area (ha)",expand = c(0.04,0), breaks = seq(0,.2,.01), 
                     labels = c("0",rep("",9),"0.1",rep("",9),"0.2"),limits = c(0,.2))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

area_treecontact

ggsave("area_treecontact.tiff",area_treecontact,dpi = 600,
       scale = 1.8, width = 6.5/3, height = 1.8, compression = "lzw")

#####################################################################
#create versions of these figures without their axis titles

tree_count_liana_noncontact_comb <- tree_count_liana_noncontact + theme(axis.title = element_blank())
tree_count_treecontact_comb <- tree_count_treecontact + theme(axis.title = element_blank())
tree_count_lianacontact_comb <- tree_count_lianacontact + theme(axis.title.x = element_blank())
dead_trees_liana_noncontact_comb <- dead_trees_liana_noncontact + theme(axis.title = element_blank())
dead_trees_treecontact_comb <- dead_trees_treecontact + theme(axis.title = element_blank())
dead_trees_lianacontact_comb <- dead_trees_lianacontact + theme(axis.title.x = element_blank())
propdead_liana_noncontact_comb <- propdead_liana_noncontact + theme(axis.title = element_blank())
propdead_treecontact_comb <- propdead_treecontact + theme(axis.title = element_blank())
propdead_lianacontact_comb <- propdead_lianacontact + theme(axis.title.x = element_blank())

necromass_liana_noncontact_comb <- necromass_liana_noncontact + theme(axis.title.y = element_blank())
necromass_treecontact_comb <- necromass_treecontact + theme(axis.title.y = element_blank())
meanDBH_liana_noncontact_comb <- meanDBH_liana_noncontact + theme(axis.title.y = element_blank())
meanDBH_treecontact_comb <- meanDBH_treecontact + theme(axis.title.y = element_blank())
area_liana_noncontact_comb <- area_liana_noncontact + theme(axis.title.y = element_blank())
area_treecontact_comb <- area_treecontact + theme(axis.title.y = element_blank())

