#Code for analyzing the influence of forest structure on lightning disturbance characteristics and patterns of current transfer
#last edited by E.M. Gora for submission on Feb. 20, 2023

#load packages
library(dplyr)
library(lme4)
library(car)
library(ggplot2)
library(extrafont)
loadfonts(device="win")

#clear workspace
rm(list=ls())

#add basic theme for plotting
theme_basis<-theme(axis.title = element_text(family = "Arial", color="black", face="bold", size=14))+
  theme(axis.text=element_text(family = "Arial",colour="black", face ="bold", size = 12)) +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"),
        axis.ticks = element_line(colour="black"))

#import data
setwd("G:/My Drive/Lightning/Electrical_connections/data/")
perstrike_lianas_damage_15m <- read.csv("perstrike_lianas_chars.csv")

###################################################
### -- liana basal area versus damaged trees -- ###
###################################################

#model of tree damage counts
mod_ba_dmg <- glm(tree_count ~ liana_ba_m2perha + tree_ba_m2perha + trees_perha, data = perstrike_lianas_damage_15m,
                  family=poisson(link="log"))
summary(mod_ba_dmg)#significant
Anova(mod_ba_dmg)
# plot(mod_ba_dmg)#decent fit - one outlier

#create the liana basal area figure
dmg_liana_ba_df <- data.frame("liana_ba_m2perha" = with(perstrike_lianas_damage_15m,
                                                seq(min(liana_ba_m2perha),max(liana_ba_m2perha),length.out=100)),
                              "trees_perha" = mean(perstrike_lianas_damage_15m$trees_perha),
                              "tree_ba_m2perha" = mean(perstrike_lianas_damage_15m$tree_ba_m2perha))

dmg_liana_ba_df$predicted_treedmg <- exp(predict(mod_ba_dmg,dmg_liana_ba_df))
dmg_liana_ba_df$predicted_treedmg_upr <- exp(predict(mod_ba_dmg,dmg_liana_ba_df) + predict(mod_ba_dmg,dmg_liana_ba_df,se.fit=TRUE)$se.fit*1.96)
dmg_liana_ba_df$predicted_treedmg_lwr <- exp(predict(mod_ba_dmg,dmg_liana_ba_df) - predict(mod_ba_dmg,dmg_liana_ba_df,se.fit=TRUE)$se.fit*1.96)

liana_ba_treedmg <- ggplot(perstrike_lianas_damage_15m, aes(x = liana_ba_m2perha, y = tree_count)) +
  geom_point() + theme_basis +
  geom_line(data=dmg_liana_ba_df,aes(x = liana_ba_m2perha,y = predicted_treedmg)) +
  geom_ribbon(data=dmg_liana_ba_df, fill = "black",alpha = 0.2,aes(x = liana_ba_m2perha,y = predicted_treedmg,
                                       ymax = predicted_treedmg_upr, ymin = predicted_treedmg_lwr)) +
  scale_y_continuous(name = expression(bold("Damaged trees"~(strike^{-1}))),
                     breaks = seq(0,120,10),limits = c(0,120),expand = c(0,0),
                     labels = c("0","","20","","40","","60","","80","","100","","120")) + 
  scale_x_continuous(expression(bold("Liana basal area"~(m^{2}~ha^{-1}))),expand=c(0,0),limits = c(0,1.55),
                     breaks = seq(0,1.5,.1),labels = c("0",rep("",4),"0.5",rep("",4),"1.0",
                                                       rep("",4),"1.5"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

liana_ba_treedmg

ggsave("liana_ba_treedmg.tiff",liana_ba_treedmg,dpi=600,compression = "lzw",
       height = 1.5, width = 6.5/3,scale = 1.8)

#create the tree basal area figure
dmg_tree_ba_df <- data.frame("tree_ba_m2perha" = with(perstrike_lianas_damage_15m,
                                                        seq(min(tree_ba_m2perha),max(tree_ba_m2perha),length.out=100)),
                              "trees_perha" = mean(perstrike_lianas_damage_15m$trees_perha),
                              "liana_ba_m2perha" = mean(perstrike_lianas_damage_15m$liana_ba_m2perha))

dmg_tree_ba_df$predicted_treedmg <- exp(predict(mod_ba_dmg,dmg_tree_ba_df))
dmg_tree_ba_df$predicted_treedmg_upr <- exp(predict(mod_ba_dmg,dmg_tree_ba_df) + predict(mod_ba_dmg,dmg_tree_ba_df,se.fit=TRUE)$se.fit*1.96)
dmg_tree_ba_df$predicted_treedmg_lwr <- exp(predict(mod_ba_dmg,dmg_tree_ba_df) - predict(mod_ba_dmg,dmg_tree_ba_df,se.fit=TRUE)$se.fit*1.96)

tree_ba_treedmg <- ggplot(perstrike_lianas_damage_15m, aes(x = tree_ba_m2perha, y = tree_count)) +
  geom_point() + theme_basis +
  scale_y_continuous(name = expression(bold("Damaged trees"~(strike^{-1}))),
                     breaks = seq(0,120,10),limits = c(0,120),expand = c(0,0),
                     labels = c("0","","20","","40","","60","","80","","100","","120")) + 
  scale_x_continuous(expression(bold("Tree basal area"~(m^{2}~ha^{-1}))),expand=c(0,0),limits = c(20,90),
                     breaks = seq(20,100,10),labels = c("20",rep("",1),"40",rep("",1),"60",rep("",1),"80",rep("",1),"100"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

tree_ba_treedmg

ggsave("tree_ba_treedmg.tiff",tree_ba_treedmg,dpi=600,compression = "lzw",
       height = 1.5, width = 6.5/3,scale = 1.8)

#create the tree count figure
dmg_tree_count_df <- data.frame("trees_perha" = with(perstrike_lianas_damage_15m,
                                                      seq(min(trees_perha),max(trees_perha),length.out=100)),
                             "liana_ba_m2perha" = mean(perstrike_lianas_damage_15m$liana_ba_m2perha),
                             "tree_ba_m2perha" = mean(perstrike_lianas_damage_15m$tree_ba_m2perha))

dmg_tree_count_df$predicted_treedmg <- exp(predict(mod_ba_dmg,dmg_tree_count_df))
dmg_tree_count_df$predicted_treedmg_upr <- exp(predict(mod_ba_dmg,dmg_tree_count_df) + predict(mod_ba_dmg,dmg_tree_count_df,se.fit=TRUE)$se.fit*1.96)
dmg_tree_count_df$predicted_treedmg_lwr <- exp(predict(mod_ba_dmg,dmg_tree_count_df) - predict(mod_ba_dmg,dmg_tree_count_df,se.fit=TRUE)$se.fit*1.96)

tree_count_treedmg <- ggplot(perstrike_lianas_damage_15m, aes(x = trees_perha, y = tree_count)) +
  geom_point() + theme_basis +
  geom_line(data=dmg_tree_count_df,aes(x = trees_perha,y = predicted_treedmg)) +
  geom_ribbon(data=dmg_tree_count_df, fill = "black",alpha = 0.2,aes(x = trees_perha,y = predicted_treedmg,
                                                                  ymax = predicted_treedmg_upr, ymin = predicted_treedmg_lwr)) +
  scale_y_continuous(name = expression(bold("Damaged trees"~(strike^{-1}))),
                     breaks = seq(0,120,10),limits = c(0,120),expand = c(0,0),
                     labels = c("0","","20","","40","","60","","80","","100","","120")) + 
  scale_x_continuous(expression(bold("Trees"~(ha^{-1}))),expand=c(0,0),limits = c(3000,6500),
                     breaks = seq(3000,7000,500),labels = c("3,000","","4,000","","5,000","","6,000","","7,000"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

tree_count_treedmg

ggsave("tree_count_treedmg.tiff",tree_count_treedmg,dpi=600,compression = "lzw",
       height = 1.5, width = 6.5/3,scale = 1.8)


################################################
### -- liana basal area versus dead trees -- ###
################################################

#liana basal area versus dead trees_perha
mod_ba_dead <- glm(total.dead ~ liana_ba_m2perha + tree_ba_m2perha + trees_perha, data = perstrike_lianas_damage_15m,
                  family=poisson(link="log"))
summary(mod_ba_dead)#strongly significant
Anova(mod_ba_dead)
# plot(mod_ba_dead)#good fit

#create the liana basal area figure
dead_liana_ba_df <- data.frame("liana_ba_m2perha" = with(perstrike_lianas_damage_15m,
                                                        seq(min(liana_ba_m2perha),max(liana_ba_m2perha),length.out=100)),
                              "trees_perha" = mean(perstrike_lianas_damage_15m$trees_perha),
                              "tree_ba_m2perha" = mean(perstrike_lianas_damage_15m$tree_ba_m2perha))

dead_liana_ba_df$predicted_treedead <- exp(predict(mod_ba_dead,dead_liana_ba_df))
dead_liana_ba_df$predicted_treedead_upr <- exp(predict(mod_ba_dead,dead_liana_ba_df) + predict(mod_ba_dead,dead_liana_ba_df,se.fit=TRUE)$se.fit*1.96)
dead_liana_ba_df$predicted_treedead_lwr <- exp(predict(mod_ba_dead,dead_liana_ba_df) - predict(mod_ba_dead,dead_liana_ba_df,se.fit=TRUE)$se.fit*1.96)

liana_ba_treedead <- ggplot(perstrike_lianas_damage_15m, aes(x = liana_ba_m2perha, y = total.dead+1)) +
  geom_point() + theme_basis +
  geom_line(data=dead_liana_ba_df,aes(x = liana_ba_m2perha,y = predicted_treedead)) +
  geom_ribbon(data=dead_liana_ba_df, fill = "black",alpha = 0.2,aes(x = liana_ba_m2perha,y = predicted_treedead,
                                                                   ymax = predicted_treedead_upr, ymin = predicted_treedead_lwr)) +
  scale_y_continuous(name = expression(bold("Killed trees"~(strike^{-1}))),
                     breaks = seq(0,60,10),expand = c(0,0),limits = c(0,60),
                     labels = c("0","","20","","40","","60"))+
  scale_x_continuous(expression(bold("Liana basal area"~(m^{2}~ha^{-1}))),expand=c(0,0),limits = c(0,1.55),
                     breaks = seq(0,1.5,.1),labels = c("0",rep("",4),"0.5",rep("",4),"1.0",
                                                       rep("",4),"1.5"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

liana_ba_treedead

ggsave("liana_ba_treedead.tiff",liana_ba_treedead,dpi=600,compression = "lzw",
       height = 1.5, width = 6.5/3,scale = 1.8)

#create the tree basal area figure
dead_tree_ba_df <- data.frame("tree_ba_m2perha" = with(perstrike_lianas_damage_15m,
                                                      seq(min(tree_ba_m2perha),max(tree_ba_m2perha),length.out=100)),
                             "trees_perha" = mean(perstrike_lianas_damage_15m$trees_perha),
                             "liana_ba_m2perha" = mean(perstrike_lianas_damage_15m$liana_ba_m2perha))

dead_tree_ba_df$predicted_treedead <- exp(predict(mod_ba_dead,dead_tree_ba_df))
dead_tree_ba_df$predicted_treedead_upr <- exp(predict(mod_ba_dead,dead_tree_ba_df) + predict(mod_ba_dead,dead_tree_ba_df,se.fit=TRUE)$se.fit*1.96)
dead_tree_ba_df$predicted_treedead_lwr <- exp(predict(mod_ba_dead,dead_tree_ba_df) - predict(mod_ba_dead,dead_tree_ba_df,se.fit=TRUE)$se.fit*1.96)

tree_ba_treedead <- ggplot(perstrike_lianas_damage_15m, aes(x = tree_ba_m2perha, y = total.dead+1)) +
  geom_point() + theme_basis +
  scale_y_continuous(name = expression(bold("Killed trees"~(strike^{-1}))),
                     breaks = seq(0,60,10),expand = c(0,0),limits = c(0,60),
                     labels = c("0","","20","","40","","60"))+
  scale_x_continuous(expression(bold("Tree basal area"~(m^{2}~ha^{-1}))),expand=c(0,0),limits = c(20,90),
                     breaks = seq(20,100,10),labels = c("20",rep("",1),"40",rep("",1),"60",rep("",1),"80",rep("",1),"100"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

tree_ba_treedead

ggsave("tree_ba_treedead.tiff",tree_ba_treedead,dpi=600,compression = "lzw",
       height = 1.5, width = 6.5/3,scale = 1.8)

#create the tree count figure
dead_total.dead_df <- data.frame("trees_perha" = with(perstrike_lianas_damage_15m,
                                                     seq(min(trees_perha),max(trees_perha),length.out=100)),
                                "liana_ba_m2perha" = mean(perstrike_lianas_damage_15m$liana_ba_m2perha),
                                "tree_ba_m2perha" = mean(perstrike_lianas_damage_15m$tree_ba_m2perha))

dead_total.dead_df$predicted_treedead <- exp(predict(mod_ba_dead,dead_total.dead_df))
dead_total.dead_df$predicted_treedead_upr <- exp(predict(mod_ba_dead,dead_total.dead_df) + predict(mod_ba_dead,dead_total.dead_df,se.fit=TRUE)$se.fit*1.96)
dead_total.dead_df$predicted_treedead_lwr <- exp(predict(mod_ba_dead,dead_total.dead_df) - predict(mod_ba_dead,dead_total.dead_df,se.fit=TRUE)$se.fit*1.96)

trees_treedead <- ggplot(perstrike_lianas_damage_15m, aes(x = trees_perha, y = total.dead+1)) +
  geom_point() + theme_basis +
  geom_line(data=dead_total.dead_df,aes(x = trees_perha,y = predicted_treedead),linetype="solid") +
  geom_ribbon(data=dead_total.dead_df, fill = "black",alpha = 0.2,aes(x = trees_perha,y = predicted_treedead,
                                                                     ymax = predicted_treedead_upr, ymin = predicted_treedead_lwr)) +
  scale_y_continuous(name = expression(bold("Killed trees"~(strike^{-1}))),
                     breaks = seq(0,60,10),expand = c(0,0),limits = c(0,60),
                     labels = c("0","","20","","40","","60"))+
  scale_x_continuous(expression(bold("Trees"~(ha^{-1}))),expand=c(0,0),limits = c(3000,6500),
                     breaks = seq(3000,7000,500),labels = c("3,000","","4,000","","5,000","","6,000","","7,000"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

trees_treedead

ggsave("trees_treedead.tiff",trees_treedead,dpi=600,compression = "lzw",
       height = 1.5, width = 6.5/3,scale = 1.8)


################################################################
### -- liana basal area versus proportion of trees killed -- ###
################################################################

#liana basal area versus proportion of trees_perha killed
mod_ba_propdead <- lm(prop.dead ~ liana_ba_m2perha + tree_ba_m2perha + trees_perha, data = perstrike_lianas_damage_15m)
summary(mod_ba_propdead)#not significant
Anova(mod_ba_propdead)#no significant relationships
# plot(mod_ba_propdead)#great fit

#create the liana basal area figure
propdead_liana_ba_df <- data.frame("liana_ba_m2perha" = with(perstrike_lianas_damage_15m,
                                                        seq(min(liana_ba_m2perha),max(liana_ba_m2perha),length.out=100)),
                              "trees_perha" = mean(perstrike_lianas_damage_15m$trees_perha),
                              "tree_ba_m2perha" = mean(perstrike_lianas_damage_15m$tree_ba_m2perha))

propdead_liana_ba_df$predicted_propdead <- exp(predict(mod_ba_propdead,propdead_liana_ba_df))
propdead_liana_ba_df$predicted_propdead_upr <- exp(predict(mod_ba_propdead,propdead_liana_ba_df) + predict(mod_ba_propdead,propdead_liana_ba_df,se.fit=TRUE)$se.fit*1.96)
propdead_liana_ba_df$predicted_propdead_lwr <- exp(predict(mod_ba_propdead,propdead_liana_ba_df) - predict(mod_ba_propdead,propdead_liana_ba_df,se.fit=TRUE)$se.fit*1.96)

liana_ba_propdead <- ggplot(perstrike_lianas_damage_15m, aes(x = liana_ba_m2perha, y = prop.dead)) +
  geom_point() + theme_basis +
  scale_y_continuous(name = "Tree mortality (%)",expand = c(0.05,0), breaks = seq(0,.7,.05),
                     labels = c("0","","10","","20","","30","","40","","50","","60","","70"))+
  scale_x_continuous(expression(bold("Liana basal area"~(m^{2}~ha^{-1}))),expand=c(0,0),limits = c(0,1.55),
                     breaks = seq(0,1.5,.1),labels = c("0",rep("",4),"0.5",rep("",4),"1.0",
                                                       rep("",4),"1.5"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

liana_ba_propdead

ggsave("liana_ba_propdead.tiff",liana_ba_propdead,dpi=600,compression = "lzw",
       height = 1.5, width = 6.5/3,scale = 1.8)

#create the tree basal area figure
propdead_tree_ba_df <- data.frame("tree_ba_m2perha" = with(perstrike_lianas_damage_15m,
                                                      seq(min(tree_ba_m2perha),max(tree_ba_m2perha),length.out=100)),
                             "trees_perha" = mean(perstrike_lianas_damage_15m$trees_perha),
                             "liana_ba_m2perha" = mean(perstrike_lianas_damage_15m$liana_ba_m2perha))

propdead_tree_ba_df$predicted_propdead <- exp(predict(mod_ba_propdead,propdead_tree_ba_df))
propdead_tree_ba_df$predicted_propdead_upr <- exp(predict(mod_ba_propdead,propdead_tree_ba_df) + predict(mod_ba_propdead,propdead_tree_ba_df,se.fit=TRUE)$se.fit*1.96)
propdead_tree_ba_df$predicted_propdead_lwr <- exp(predict(mod_ba_propdead,propdead_tree_ba_df) - predict(mod_ba_propdead,propdead_tree_ba_df,se.fit=TRUE)$se.fit*1.96)

tree_ba_propdead <- ggplot(perstrike_lianas_damage_15m, aes(x = tree_ba_m2perha, y = prop.dead)) +
  geom_point() + theme_basis +
  scale_y_continuous(name = "Tree mortality (%)",expand = c(0.05,0), breaks = seq(0,.7,.05),
                     labels = c("0","","10","","20","","30","","40","","50","","60","","70"))+
  scale_x_continuous(expression(bold("Tree basal area"~(m^{2}~ha^{-1}))),expand=c(0,0),limits = c(20,90),
                     breaks = seq(20,100,10),labels = c("20",rep("",1),"40",rep("",1),"60",rep("",1),"80",rep("",1),"100"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

tree_ba_propdead

ggsave("tree_ba_propdead.tiff",tree_ba_propdead,dpi=600,compression = "lzw",
       height = 1.5, width = 6.5/3,scale = 1.8)

#create the tree count figure
trees_propdead_df <- data.frame("trees_perha" = with(perstrike_lianas_damage_15m,
                                                     seq(min(trees_perha),max(trees_perha),length.out=100)),
                                "liana_ba_m2perha" = mean(perstrike_lianas_damage_15m$liana_ba_m2perha),
                                "tree_ba_m2perha" = mean(perstrike_lianas_damage_15m$tree_ba_m2perha))

trees_propdead_df$predicted_propdead <- exp(predict(mod_ba_propdead,trees_propdead_df))
trees_propdead_df$predicted_propdead_upr <- exp(predict(mod_ba_propdead,trees_propdead_df) + predict(mod_ba_propdead,trees_propdead_df,se.fit=TRUE)$se.fit*1.96)
trees_propdead_df$predicted_propdead_lwr <- exp(predict(mod_ba_propdead,trees_propdead_df) - predict(mod_ba_propdead,trees_propdead_df,se.fit=TRUE)$se.fit*1.96)

trees_propdead <- ggplot(perstrike_lianas_damage_15m, aes(x = trees_perha, y = prop.dead)) +
  geom_point() + theme_basis +
  scale_y_continuous(name = "Tree mortality (%)",expand = c(0.05,0), breaks = seq(0,.7,.05),
                     labels = c("0","","10","","20","","30","","40","","50","","60","","70"))+
  scale_x_continuous(expression(bold("Trees"~(ha^{-1}))),expand=c(0,0),limits = c(3000,6500),
                     breaks = seq(3000,7000,500),labels = c("3,000","","4,000","","5,000","","6,000","","7,000"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

trees_propdead

ggsave("trees_propdead.tiff",trees_propdead,dpi=600,compression = "lzw",
       height = 1.5, width = 6.5/3,scale = 1.8)


####################################################
### -- liana basal area versus disturbed area -- ###
####################################################


#liana basal area versus disturbed area
mod_ba_area <- lm(disturbed_area/1000 ~ liana_ba_m2perha + tree_ba_m2perha + trees_perha, data = perstrike_lianas_damage_15m)
summary(mod_ba_area)#not significant
Anova(mod_ba_area)#no significant relationships
# plot(mod_ba_area)#good fit

#create the liana basal area figure
area_liana_ba_df <- data.frame("liana_ba_m2perha" = with(perstrike_lianas_damage_15m,
                                                             seq(min(liana_ba_m2perha),max(liana_ba_m2perha),length.out=100)),
                                   "trees_perha" = mean(perstrike_lianas_damage_15m$trees_perha),
                                   "tree_ba_m2perha" = mean(perstrike_lianas_damage_15m$tree_ba_m2perha))

area_liana_ba_df$predicted_area <- exp(predict(mod_ba_area,area_liana_ba_df))
area_liana_ba_df$predicted_area_upr <- exp(predict(mod_ba_area,area_liana_ba_df) + predict(mod_ba_area,area_liana_ba_df,se.fit=TRUE)$se.fit*1.96)
area_liana_ba_df$predicted_area_lwr <- exp(predict(mod_ba_area,area_liana_ba_df) - predict(mod_ba_area,area_liana_ba_df,se.fit=TRUE)$se.fit*1.96)

liana_ba_area <- ggplot(perstrike_lianas_damage_15m, aes(x = liana_ba_m2perha, y = disturbed_area/10000)) +
  geom_point() + theme_basis +
  scale_y_continuous(name = "Disturbed area (ha)",expand = c(0.04,0), breaks = seq(0,.2,.01), 
                     labels = c("0",rep("",9),"0.1",rep("",9),"0.2"),limits = c(0,.2))+
  scale_x_continuous(expression(bold("Liana basal area"~(m^{2}~ha^{-1}))),expand=c(0,0),limits = c(0,1.55),
                     breaks = seq(0,1.5,.1),labels = c("0",rep("",4),"0.5",rep("",4),"1.0",
                                                       rep("",4),"1.5"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

liana_ba_area

ggsave("liana_ba_area.tiff",liana_ba_area,dpi=600,compression = "lzw",
       height = 1.5, width = 6.5/3,scale = 1.8)

#create the tree basal area figure
area_tree_ba_df <- data.frame("tree_ba_m2perha" = with(perstrike_lianas_damage_15m,
                                                           seq(min(tree_ba_m2perha),max(tree_ba_m2perha),length.out=100)),
                                  "trees_perha" = mean(perstrike_lianas_damage_15m$trees_perha),
                                  "liana_ba_m2perha" = mean(perstrike_lianas_damage_15m$liana_ba_m2perha))

area_tree_ba_df$predicted_area <- exp(predict(mod_ba_area,area_tree_ba_df))
area_tree_ba_df$predicted_area_upr <- exp(predict(mod_ba_area,area_tree_ba_df) + predict(mod_ba_area,area_tree_ba_df,se.fit=TRUE)$se.fit*1.96)
area_tree_ba_df$predicted_area_lwr <- exp(predict(mod_ba_area,area_tree_ba_df) - predict(mod_ba_area,area_tree_ba_df,se.fit=TRUE)$se.fit*1.96)

tree_ba_area <- ggplot(perstrike_lianas_damage_15m, aes(x = tree_ba_m2perha, y = disturbed_area/10000)) +
  geom_point() + theme_basis +
  scale_y_continuous(name = "Disturbed area (ha)",expand = c(0.04,0), breaks = seq(0,.2,.01), 
                     labels = c("0",rep("",9),"0.1",rep("",9),"0.2"),limits = c(0,.2))+
  scale_x_continuous(expression(bold("Tree basal area"~(m^{2}~ha^{-1}))),expand=c(0,0),limits = c(20,90),
                     breaks = seq(20,100,10),labels = c("20",rep("",1),"40",rep("",1),"60",rep("",1),"80",rep("",1),"100"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

tree_ba_area

ggsave("tree_ba_area.tiff",tree_ba_area,dpi=600,compression = "lzw",
       height = 1.5, width = 6.5/3,scale = 1.8)

#create the tree count figure
trees_area_df <- data.frame("trees_perha" = with(perstrike_lianas_damage_15m,
                                                     seq(min(trees_perha),max(trees_perha),length.out=100)),
                                "liana_ba_m2perha" = mean(perstrike_lianas_damage_15m$liana_ba_m2perha),
                                "tree_ba_m2perha" = mean(perstrike_lianas_damage_15m$tree_ba_m2perha))

trees_area_df$predicted_area <- exp(predict(mod_ba_area,trees_area_df))
trees_area_df$predicted_area_upr <- exp(predict(mod_ba_area,trees_area_df) + predict(mod_ba_area,trees_area_df,se.fit=TRUE)$se.fit*1.96)
trees_area_df$predicted_area_lwr <- exp(predict(mod_ba_area,trees_area_df) - predict(mod_ba_area,trees_area_df,se.fit=TRUE)$se.fit*1.96)

trees_area <- ggplot(perstrike_lianas_damage_15m, aes(x = trees_perha, y = disturbed_area/10000)) +
  geom_point() + theme_basis +
  scale_y_continuous(name = "Disturbed area (ha)",expand = c(0.04,0), breaks = seq(0,.2,.01), 
                     labels = c("0",rep("",9),"0.1",rep("",9),"0.2"),limits = c(0,.2))+
  scale_x_continuous(expression(bold("Trees"~(ha^{-1}))),expand=c(0,0),limits = c(3000,6500),
                     breaks = seq(3000,7000,500),labels = c("3,000","","4,000","","5,000","","6,000","","7,000"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

trees_area

ggsave("trees_area.tiff",trees_area,dpi=600,compression = "lzw",
       height = 1.5, width = 6.5/3,scale = 1.8)

##########################################################
### -- liana basal area versus total necromass area -- ###
##########################################################


#liana basal area versus total necromass
mod_ba_necromass <- lm(log(total_necromass_kg/1000) ~ liana_ba_m2perha + tree_ba_m2perha + trees_perha, data = perstrike_lianas_damage_15m)
summary(mod_ba_necromass)#not significant
Anova(mod_ba_necromass)#no significant relationships
# plot(mod_ba_necromass)#excellent fit

#create the liana basal area figure
area_liana_ba_df <- data.frame("liana_ba_m2perha" = with(perstrike_lianas_damage_15m,
                                                         seq(min(liana_ba_m2perha),max(liana_ba_m2perha),length.out=100)),
                               "trees_perha" = mean(perstrike_lianas_damage_15m$trees_perha),
                               "tree_ba_m2perha" = mean(perstrike_lianas_damage_15m$tree_ba_m2perha))

area_liana_ba_df$predicted_necromass <- exp(predict(mod_ba_necromass,area_liana_ba_df))
area_liana_ba_df$predicted_necromass_upr <- exp(predict(mod_ba_necromass,area_liana_ba_df) + predict(mod_ba_necromass,area_liana_ba_df,se.fit=TRUE)$se.fit*1.96)
area_liana_ba_df$predicted_necromass_lwr <- exp(predict(mod_ba_necromass,area_liana_ba_df) - predict(mod_ba_necromass,area_liana_ba_df,se.fit=TRUE)$se.fit*1.96)

liana_ba_necromass <- ggplot(perstrike_lianas_damage_15m, aes(x = liana_ba_m2perha, y = total_necromass_kg/1000)) +
  geom_point() + theme_basis +
  scale_y_continuous(name = "Biomass turnover (Mg)",expand = c(0.04,0), breaks = seq(0,40,5), 
                     labels = c("0","","10","","20","","30","","40"))+
  scale_x_continuous(expression(bold("Liana basal area"~(m^{2}~ha^{-1}))),expand=c(0,0),limits = c(0,1.55),
                     breaks = seq(0,1.5,.1),labels = c("0",rep("",4),"0.5",rep("",4),"1.0",
                                                       rep("",4),"1.5"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

liana_ba_necromass

ggsave("liana_ba_necromass.tiff",liana_ba_necromass,dpi=600,compression = "lzw",
       height = 1.5, width = 6.5/3,scale = 1.8)

#create the tree basal area figure
area_tree_ba_df <- data.frame("tree_ba_m2perha" = with(perstrike_lianas_damage_15m,
                                                       seq(min(tree_ba_m2perha),max(tree_ba_m2perha),length.out=100)),
                              "trees_perha" = mean(perstrike_lianas_damage_15m$trees_perha),
                              "liana_ba_m2perha" = mean(perstrike_lianas_damage_15m$liana_ba_m2perha))

area_tree_ba_df$predicted_necromass <- exp(predict(mod_ba_necromass,area_tree_ba_df))
area_tree_ba_df$predicted_necromass_upr <- exp(predict(mod_ba_necromass,area_tree_ba_df) + predict(mod_ba_necromass,area_tree_ba_df,se.fit=TRUE)$se.fit*1.96)
area_tree_ba_df$predicted_necromass_lwr <- exp(predict(mod_ba_necromass,area_tree_ba_df) - predict(mod_ba_necromass,area_tree_ba_df,se.fit=TRUE)$se.fit*1.96)

tree_ba_necromass <- ggplot(perstrike_lianas_damage_15m, aes(x = tree_ba_m2perha, y = total_necromass_kg/1000)) +
  geom_point() + theme_basis +
  scale_y_continuous(name = "Biomass turnover (Mg)",expand = c(0.04,0), breaks = seq(0,40,5), 
                     labels = c("0","","10","","20","","30","","40"))+
  scale_x_continuous(expression(bold("Tree basal area"~(m^{2}~ha^{-1}))),expand=c(0,0),limits = c(20,90),
                     breaks = seq(20,100,10),labels = c("20",rep("",1),"40",rep("",1),"60",rep("",1),"80",rep("",1),"100"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

tree_ba_necromass

ggsave("tree_ba_necromass.tiff",tree_ba_necromass,dpi=600,compression = "lzw",
       height = 1.5, width = 6.5/3,scale = 1.8)

#create the tree count figure
trees_necromass_df <- data.frame("trees_perha" = with(perstrike_lianas_damage_15m,
                                                 seq(min(trees_perha),max(trees_perha),length.out=100)),
                            "liana_ba_m2perha" = mean(perstrike_lianas_damage_15m$liana_ba_m2perha),
                            "tree_ba_m2perha" = mean(perstrike_lianas_damage_15m$tree_ba_m2perha))

trees_necromass_df$predicted_necromass <- exp(predict(mod_ba_necromass,trees_necromass_df))
trees_necromass_df$predicted_necromass_upr <- exp(predict(mod_ba_necromass,trees_necromass_df) + predict(mod_ba_necromass,trees_necromass_df,se.fit=TRUE)$se.fit*1.96)
trees_necromass_df$predicted_necromass_lwr <- exp(predict(mod_ba_necromass,trees_necromass_df) - predict(mod_ba_necromass,trees_necromass_df,se.fit=TRUE)$se.fit*1.96)

trees_necromass <- ggplot(perstrike_lianas_damage_15m, aes(x = trees_perha, y = total_necromass_kg/1000)) +
  geom_point() + theme_basis +
  scale_y_continuous(name = "Biomass turnover (Mg)",expand = c(0.04,0), breaks = seq(0,40,5), 
                     labels = c("0","","10","","20","","30","","40"))+
  scale_x_continuous(expression(bold("Trees"~(ha^{-1}))),expand=c(0,0),limits = c(3000,6500),
                     breaks = seq(3000,7000,500),labels = c("3,000","","4,000","","5,000","","6,000","","7,000"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

trees_necromass

ggsave("trees_necromass.tiff",trees_necromass,dpi=600,compression = "lzw",
       height = 1.5, width = 6.5/3,scale = 1.8)


###########################################################
### -- liana basal area versus average tree diameter -- ###
###########################################################

#liana basal area versus average tree diameter
mod_ba_meanDBH <- lm(mean_DBH ~ liana_ba_m2perha + tree_ba_m2perha + trees_perha, data = perstrike_lianas_damage_15m)
summary(mod_ba_meanDBH)#marginally significant
Anova(mod_ba_meanDBH)#this decreases with liana basal area
# plot(mod_ba_meanDBH)#great fit

#create the liana basal area figure
area_liana_ba_df <- data.frame("liana_ba_m2perha" = with(perstrike_lianas_damage_15m,
                                                         seq(min(liana_ba_m2perha),max(liana_ba_m2perha),length.out=100)),
                               "trees_perha" = mean(perstrike_lianas_damage_15m$trees_perha),
                               "tree_ba_m2perha" = mean(perstrike_lianas_damage_15m$tree_ba_m2perha))

area_liana_ba_df$predicted_meanDBH <- predict(mod_ba_meanDBH,area_liana_ba_df)
area_liana_ba_df$predicted_meanDBH_upr <- predict(mod_ba_meanDBH,area_liana_ba_df) + predict(mod_ba_meanDBH,area_liana_ba_df,se.fit=TRUE)$se.fit*1.96
area_liana_ba_df$predicted_meanDBH_lwr <- predict(mod_ba_meanDBH,area_liana_ba_df) - predict(mod_ba_meanDBH,area_liana_ba_df,se.fit=TRUE)$se.fit*1.96

liana_ba_meanDBH <- ggplot(perstrike_lianas_damage_15m, aes(x = liana_ba_m2perha, y = mean_DBH)) +
  geom_point() + theme_basis +
  geom_line(data=area_liana_ba_df,aes(x = liana_ba_m2perha,y = predicted_meanDBH)) +
  geom_ribbon(data=area_liana_ba_df, fill = "black",alpha = 0.2,aes(x = liana_ba_m2perha,y = predicted_meanDBH,
                                                                   ymax = predicted_meanDBH_upr, ymin = predicted_meanDBH_lwr)) +
  scale_y_continuous(name = "Mean DBH (mm)",expand = c(0,0), breaks = seq(0,800,50),limits =c(50,800),
                     labels = c("0","","100","","200","","300","","400","","500","","600","","700","","800"))+
  scale_x_continuous(expression(bold("Liana basal area"~(m^{2}~ha^{-1}))),expand=c(0,0),limits = c(0,1.55),
                     breaks = seq(0,1.5,.1),labels = c("0",rep("",4),"0.5",rep("",4),"1.0",
                                                       rep("",4),"1.5"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

liana_ba_meanDBH

ggsave("liana_ba_meanDBH.tiff",liana_ba_meanDBH,dpi=600,compression = "lzw",
       height = 1.5, width = 6.5/3,scale = 1.8)

#create the tree basal area figure
tree_ba_meanDBH <- ggplot(perstrike_lianas_damage_15m, aes(x = tree_ba_m2perha, y = mean_DBH)) +
  geom_point() + theme_basis +
  scale_y_continuous(name = "Mean DBH (mm)",expand = c(0,0), breaks = seq(0,800,50),limits =c(50,800),
                     labels = c("0","","100","","200","","300","","400","","500","","600","","700","","800"))+
  scale_x_continuous(expression(bold("Tree basal area"~(m^{2}~ha^{-1}))),expand=c(0,0),limits = c(20,90),
                     breaks = seq(20,100,10),labels = c("20",rep("",1),"40",rep("",1),"60",rep("",1),"80",rep("",1),"100"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

tree_ba_meanDBH

ggsave("tree_ba_meanDBH.tiff",tree_ba_meanDBH,dpi=600,compression = "lzw",
       height = 1.5, width = 6.5/3,scale = 1.8)

#create the tree count figure
trees_meanDBH <- ggplot(perstrike_lianas_damage_15m, aes(x = trees_perha, y = mean_DBH)) +
  geom_point() + theme_basis +
  scale_y_continuous(name = "Mean DBH (mm)",expand = c(0,0), breaks = seq(0,800,50),limits =c(50,800),
                     labels = c("0","","100","","200","","300","","400","","500","","600","","700","","800"))+
  scale_x_continuous(expression(bold("Trees"~(ha^{-1}))),expand=c(0,0),limits = c(3000,6500),
                     breaks = seq(3000,7000,500),labels = c("3,000","","4,000","","5,000","","6,000","","7,000"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

trees_meanDBH

ggsave("trees_meanDBH.tiff",trees_meanDBH,dpi=600,compression = "lzw",
       height = 1.5, width = 6.5/3,scale = 1.8)



#########################################################################
### -- liana basal area versus the DBH of the directly struck tree -- ###
#########################################################################

#liana basal area versus the central tree diameter
mod_ba_meanDBH <- lm(DBH.mm ~ liana_ba_m2perha + tree_ba_m2perha + trees_perha, data = perstrike_lianas_damage_15m)
summary(mod_ba_meanDBH)#marginally significant
Anova(mod_ba_meanDBH)#this decreases with liana basal area
# plot(mod_ba_meanDBH)#excellent fit

##################################################################################
### --- Test how differently sized trees are influenced by forest structure -- ###
##################################################################################

#model of tree damage counts
mod_ba_dmg_un10cm <- glm(tree_count_un10cm ~ liana_ba_m2perha + tree_ba_m2perha + trees_perha, data = perstrike_lianas_damage_15m,
                  family=poisson(link="log"))
summary(mod_ba_dmg_un10cm)#significant
Anova(mod_ba_dmg_un10cm)
# plot(mod_ba_dmg_un10cm)#decent fit

mod_ba_dmg_un50cm <- glm(tree_count_un50cm ~ liana_ba_m2perha + tree_ba_m2perha + trees_perha, data = perstrike_lianas_damage_15m,
                         family=poisson(link="log"))
summary(mod_ba_dmg_un50cm)#marginally non-significant effect of lianas
Anova(mod_ba_dmg_un50cm)
# plot(mod_ba_dmg_un50cm)#great fit

mod_ba_dmg_ov50cm <- glm(tree_count_ov50cm ~ liana_ba_m2perha + tree_ba_m2perha + trees_perha, data = perstrike_lianas_damage_15m,
                         family=poisson(link="log"))
summary(mod_ba_dmg_ov50cm)#not significant
Anova(mod_ba_dmg_ov50cm)
# plot(mod_ba_dmg_ov50cm)#great fit

#create the liana basal area figure
dmg_un10cm_liana_ba_df <- data.frame("liana_ba_m2perha" = with(perstrike_lianas_damage_15m,
                                                        seq(min(liana_ba_m2perha),max(liana_ba_m2perha),length.out=100)),
                              "trees_perha" = mean(perstrike_lianas_damage_15m$trees_perha),
                              "tree_ba_m2perha" = mean(perstrike_lianas_damage_15m$tree_ba_m2perha))

dmg_un10cm_liana_ba_df$predicted_treedmg <- exp(predict(mod_ba_dmg_un10cm,dmg_un10cm_liana_ba_df))
dmg_un10cm_liana_ba_df$predicted_treedmg_upr <- exp(predict(mod_ba_dmg_un10cm,dmg_un10cm_liana_ba_df) + predict(mod_ba_dmg_un10cm,dmg_un10cm_liana_ba_df,se.fit=TRUE)$se.fit*1.96)
dmg_un10cm_liana_ba_df$predicted_treedmg_lwr <- exp(predict(mod_ba_dmg_un10cm,dmg_un10cm_liana_ba_df) - predict(mod_ba_dmg_un10cm,dmg_un10cm_liana_ba_df,se.fit=TRUE)$se.fit*1.96)

liana_ba_treedmg_un10cm <- ggplot(perstrike_lianas_damage_15m, aes(x = liana_ba_m2perha, y = tree_count_un10cm)) +
  geom_point() + theme_basis +
  geom_line(data=dmg_un10cm_liana_ba_df,aes(x = liana_ba_m2perha,y = predicted_treedmg)) +
  geom_ribbon(data=dmg_un10cm_liana_ba_df, fill = "black",alpha = 0.2,aes(x = liana_ba_m2perha,y = predicted_treedmg,
                                                                   ymax = predicted_treedmg_upr, ymin = predicted_treedmg_lwr)) +
  scale_y_continuous(name = expression(bold("Small trees"~(strike^{-1}))),
                     breaks = seq(0,120,10),limits = c(0,90),expand = c(0.04,0),
                     labels = c("0","","20","","40","","60","","80","","100","","120")) + 
  scale_x_continuous(expression(bold("Liana basal area"~(m^{2}~ha^{-1}))),expand=c(0,0),limits = c(0,1.55),
                     breaks = seq(0,1.5,.1),labels = c("0",rep("",4),"0.5",rep("",4),"1.0",
                                                       rep("",4),"1.5"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

liana_ba_treedmg_un10cm

ggsave("liana_ba_treedmg_un10cm.tiff",liana_ba_treedmg_un10cm,dpi=600,compression = "lzw",
       height = 1.5, width = 6.5/3,scale = 1.8)

#plot tree basal area
#create the tree basal area figure
tree_ba_treedmg_un10cm <- ggplot(perstrike_lianas_damage_15m, aes(x = tree_ba_m2perha, y = tree_count_un10cm)) +
  geom_point() + theme_basis +
  scale_y_continuous(name = expression(bold("Small trees"~(strike^{-1}))),
                     breaks = seq(0,120,10),limits = c(0,90),expand = c(0.04,0),
                     labels = c("0","","20","","40","","60","","80","","100","","120")) + 
  scale_x_continuous(expression(bold("Tree basal area"~(m^{2}~ha^{-1}))),expand=c(0,0),limits = c(20,90),
                     breaks = seq(20,100,10),labels = c("20",rep("",1),"40",rep("",1),"60",rep("",1),"80",rep("",1),"100"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

tree_ba_treedmg_un10cm

ggsave("tree_ba_treedmg_un10cm.tiff",tree_ba_treedmg_un10cm,dpi=600,compression = "lzw",
       height = 1.5, width = 6.5/3,scale = 1.8)

#create the tree count figure
trees_treedmg_un10cm <- ggplot(perstrike_lianas_damage_15m, aes(x = trees_perha, y = tree_count_un10cm)) +
  geom_point() + theme_basis +
  scale_y_continuous(name = expression(bold("Small trees"~(strike^{-1}))),
                     breaks = seq(0,120,10),limits = c(0,90),expand = c(0.04,0),
                     labels = c("0","","20","","40","","60","","80","","100","","120")) + 
  scale_x_continuous(expression(bold("Trees"~(ha^{-1}))),expand=c(0,0),limits = c(3000,6500),
                     breaks = seq(3000,7000,500),labels = c("3,000","","4,000","","5,000","","6,000","","7,000"))+
  theme(plot.margin = margin(.7,.2,.2,.2,"cm"))

trees_treedmg_un10cm

ggsave("trees_treedmg_un10cm.tiff",trees_treedmg_un10cm,dpi=600,compression = "lzw",
       height = 1.5, width = 6.5/3,scale = 1.8)

#################################################################################
### --- Does variation in liana basal area predict current transfer damage -- ###
#################################################################################
#select all strikes with current transfer data ("total_assigned_current" values of 1 simply identify the directly struck tree)
perstrike_transferonly_15m <- perstrike_lianas_damage_15m[perstrike_lianas_damage_15m$total_assigned_current>1,]
str(perstrike_transferonly_15m)
length(unique(perstrike_transferonly_15m$strike))#9 strikes with current transfer data

#perform beta regression
library(betareg)
library(lmtest)
perstrike_transferonly_15m$prop.lianas_no0 <- ifelse(perstrike_transferonly_15m$prop.lianas==0,
                                       0.025,
                                       perstrike_transferonly_15m$prop.lianas)

perstrike_transferonly_15m$prop.liana_contact_no0 <- ifelse(perstrike_transferonly_15m$prop.liana_contact==0,
                                                     0.025,
                                                     perstrike_transferonly_15m$prop.liana_contact)

perstrike_transferonly_15m$prop.liana_flashover_no0 <- ifelse(perstrike_transferonly_15m$prop.liana_flashover==0,
                                                     0.025,
                                                     perstrike_transferonly_15m$prop.liana_flashover)


#examine how liana contact varies with local liana densities
betamod_ba_propliana_contact <- betareg(prop.liana_contact_no0 ~ liana_ba_m2perha, data = perstrike_transferonly_15m,
                                 link = "logit")
betamod_ba_propliana_contact_null <- betareg(prop.liana_contact_no0 ~ 1, data = perstrike_transferonly_15m,
                                        link = "logit")
waldtest(betamod_ba_propliana_contact,betamod_ba_propliana_contact_null)
summary(betamod_ba_propliana_contact)
# plot(betamod_ba_propliana_contact)#good fit

###########################################################################
### -- Examine how liana flashover varies with local liana densities -- ###
###########################################################################

betamod_ba_propliana_flashover <- betareg(prop.liana_flashover_no0 ~ liana_ba_m2perha, data = perstrike_transferonly_15m,
                                        link = "logit")
betamod_ba_propliana_flashover_null <- betareg(prop.liana_flashover_no0 ~ 1, data = perstrike_transferonly_15m,
                                          link = "logit")
Anova(betamod_ba_propliana_flashover)#not significant Wald test
summary(betamod_ba_propliana_flashover)
# plot(betamod_ba_propliana_flashover)#decent fit

################################################################
### -- test for autocorrelation and vif in the predictors -- ###
################################################################
#test variance inflation factors and correlations among forest stucture predictors
vif(mod_ba_dmg)
vif(mod_ba_dead)
vif(mod_ba_propdead)
vif(mod_ba_area)
vif(mod_ba_necromass)

cor.test(perstrike_lianas_damage_15m$trees_perha,
         perstrike_lianas_damage_15m$liana_ba_m2perha)#R = 0.05, P = 0.82
cor.test(perstrike_lianas_damage_15m$tree_ba_m2perha,
         perstrike_lianas_damage_15m$liana_ba_m2perha)#R = -0.15, P = 0.50
cor.test(perstrike_lianas_damage_15m$tree_ba_m2perha,
         perstrike_lianas_damage_15m$trees_perha)#R = 0.03, P = 0.89
#no strong correlations or high VIF values
